@@ -69,11 +69,10 @@ extern VexGuestLayout s390xGuest_layout;
 /*------------------------------------------------------------*/
 /*--- Helper functions.                                    ---*/
 /*------------------------------------------------------------*/
-void s390x_dirtyhelper_EX(ULong torun);
+void s390x_dirtyhelper_EX(ULong torun, Addr64 addr);
 ULong s390x_dirtyhelper_STCK(ULong *addr);
 ULong s390x_dirtyhelper_STCKF(ULong *addr);
 ULong s390x_dirtyhelper_STCKE(ULong *addr);
-ULong s390x_dirtyhelper_STFLE(VexGuestS390XState *guest_state, ULong *addr);
 void  s390x_dirtyhelper_CUxy(UChar *addr, ULong data, ULong num_bytes);
 ULong s390x_dirtyhelper_vec_op(VexGuestS390XState *guest_state,
                                ULong details);
@@ -254,6 +253,9 @@ UInt s390_calculate_cond(ULong mask, ULong op, ULong dep1, ULong dep2,
 /* Last target instruction for the EX helper */
 extern ULong last_execute_target;
 
+/* Base for relative addressing while processing EX */
+extern Addr64 guest_IA_rel_base;
+
 /*------------------------------------------------------------*/
 /*--- Vector helpers.                                      ---*/
 /*------------------------------------------------------------*/
@@ -278,6 +280,11 @@ typedef enum {
    S390_VEC_OP_VFMAX,
    S390_VEC_OP_VBPERM,
    S390_VEC_OP_VMSL,
+   S390_VEC_OP_VCNF,
+   S390_VEC_OP_VCLFNH,
+   S390_VEC_OP_VCFN,
+   S390_VEC_OP_VCLFNL,
+   S390_VEC_OP_VCRNF,
    S390_VEC_OP_LAST             // supposed to be the last element in enum
 } s390x_vec_op_t;
 
@@ -295,12 +302,13 @@ typedef union {
       unsigned int v4 : 5;        // argument two of operation or
                                   // zero for unary and binary operations
 
+      unsigned int m3 : 4;        // field m3 of insn or zero if it's missing
       unsigned int m4 : 4;        // field m4 of insn or zero if it's missing
       unsigned int m5 : 4;        // field m5 of insn or zero if it's missing
       unsigned int m6 : 4;        // field m6 of insn or zero if it's missing
       unsigned int i3 : 12;       // field i3 of insn or zero if it's missing
       unsigned int read_only: 1;  // don't write result to Guest State
-      unsigned int reserved : 11; // reserved for future
+      unsigned int reserved : 7; // reserved for future
    };
    ULong serialized;
 } s390x_vec_op_details_t;
