@@ -943,6 +943,10 @@ extern UInt s390_host_hwcaps;
                       (s390_host_hwcaps & (VEX_HWCAPS_S390X_LSC2))
 #define s390_host_has_vxe \
                       (s390_host_hwcaps & (VEX_HWCAPS_S390X_VXE))
+#define s390_host_has_nnpa \
+                      (s390_host_hwcaps & (VEX_HWCAPS_S390X_NNPA))
+#define s390_host_has_dflt \
+                      (s390_host_hwcaps & (VEX_HWCAPS_S390X_DFLT))
 #endif /* ndef __VEX_HOST_S390_DEFS_H */
 
 /*---------------------------------------------------------------*/
