@@ -129,6 +129,8 @@ static char *find_client(const char *clientname)
 
       if (access(fullname, R_OK|X_OK) == 0)
          return fullname;
+      else if (access(fullname, X_OK) == 0)
+	 barf("Need read permission on %s", fullname);
    }
    free(fullname);
 
@@ -158,7 +160,7 @@ static const char *select_platform(const char *clientname)
    if (strcmp (client, clientname) != 0)
       VG_(debugLog)(2, "launcher", "selecting platform for '%s'\n", client);
 
-   if ((fd = open(clientname, O_RDONLY)) < 0) {
+   if ((fd = open(client, O_RDONLY)) < 0) {
      return_null:
       free (client);
       return NULL;
