@@ -582,7 +582,28 @@ static void set_CEnt ( const DiImage* img, UInt entNo, DiOffT off )
 
    if (img->source.is_local) {
       // Simple: just read it
+
+      // PJF not quite so simple - see
+      // https://bugs.kde.org/show_bug.cgi?id=480405
+      // if img->source.fd was opened with O_DIRECT the memory needs
+      // to be aligned and also the length
+      // that's a lot of hassle just to take a quick peek to see if
+      // is an ELF binary so just twiddle the flag before and after
+      // peeking.
+      // This doesn't seem to be a problem on FreeBSD. I haven't tested
+      // on macOS or Solaris, hence the conditional compilation
+#if defined(VKI_O_DIRECT)
+      Int flags = VG_(fcntl)(img->source.fd, VKI_F_GETFL, 0);
+      if (flags & VKI_O_DIRECT) {
+          VG_(fcntl)(img->source.fd, VKI_F_SETFL, flags & ~VKI_O_DIRECT);
+      }
+#endif
       SysRes sr = VG_(pread)(img->source.fd, &ce->data[0], (Int)len, off);
+#if defined(VKI_O_DIRECT)
+      if (flags & VKI_O_DIRECT) {
+         VG_(fcntl)(img->source.fd, VKI_F_SETFL, flags);
+      }
+#endif
       vg_assert(!sr_isError(sr));
    } else {
       // Not so simple: poke the server
@@ -1221,6 +1242,20 @@ Int ML_(img_strcmp_c)(DiImage* img, DiOffT off1, const HChar* str2)
    }
 }
 
+Int ML_(img_strcmp_n)(DiImage* img, DiOffT off1, const HChar* str2, Word n)
+{
+   ensure_valid(img, off1, 1, "ML_(img_strcmp_c)");
+   while (n) {
+      UChar c1 = get(img, off1);
+      UChar c2 = *(const UChar*)str2;
+      if (c1 < c2) return -1;
+      if (c1 > c2) return 1;
+      if (c1 == 0) return 0;
+      off1++; str2++; --n;
+   }
+   return 0;
+}
+
 UChar ML_(img_get_UChar)(DiImage* img, DiOffT offset)
 {
    ensure_valid(img, offset, 1, "ML_(img_get_UChar)");
