@@ -768,6 +768,8 @@ const HChar* ML_(pp_DW_children) ( DW_children hashch );
 const HChar* ML_(pp_DW_TAG)      ( DW_TAG tag );
 const HChar* ML_(pp_DW_FORM)     ( DW_FORM form );
 const HChar* ML_(pp_DW_AT)       ( DW_AT attr );
+const HChar* ML_(pp_DW_LLE)      ( DW_LLE entry );
+const HChar* ML_(pp_DW_RLE)      ( DW_RLE entry );
 
 
 /* --- To do with evaluation of Dwarf expressions --- */
