@@ -177,7 +177,7 @@
            "std %%f5, 64(%1);"                            \
            "std %%f6, 72(%1);"                            \
            "std %%f7, 80(%1);"                            \
-           : /* out */   "=r" (ia)                        \
+           : /* out */   "=&r" (ia)                       \
            : /* in */    "a" (&block[0])                  \
            : /* trash */ "memory"                         \
         );                                                \
