@@ -533,6 +533,14 @@ void VG_(redir_notify_new_DebugInfo)( DebugInfo* newdi )
          alloc_symname_array(sym_name_pri, sym_names_sec, &twoslots[0]);
       const HChar** names;
       for (names = names_init; *names; names++) {
+         /*
+          * For Ada demangling, the language doesn't use a regular
+          * prefix like _Z or _R, so look for a common symbol and
+          * set a global flag.
+          */
+         if (!isText && VG_(strcmp)(*names, "__gnat_ada_main_program_name") == 0) {
+            VG_(lang_is_ada) = True;
+         }
          isGlobal = False;
          ok = VG_(maybe_Z_demangle)( *names,
                                      &demangled_sopatt,
@@ -1410,6 +1418,15 @@ void VG_(redir_initialise) ( void )
          complain_about_stripped_glibc_ldso
 #        endif
       );   
+      add_hardwired_spec(
+         "ld-linux-x86-64.so.2", "strcmp",
+         (Addr)&VG_(amd64_linux_REDIR_FOR_strcmp),
+#        ifndef GLIBC_MANDATORY_STRLEN_REDIRECT
+         NULL
+#        else
+         complain_about_stripped_glibc_ldso
+#        endif
+      );
    }
 
 #  elif defined(VGP_ppc32_linux)
@@ -1558,7 +1575,7 @@ void VG_(redir_initialise) ( void )
 #     endif
    }
 
-#  elif defined(VGP_x86_freebsd) || defined(VGP_amd64_freebsd)
+#  elif defined(VGP_x86_freebsd) || defined(VGP_amd64_freebsd) || defined(VGP_arm64_freebsd)
 /* XXX do something real if needed */
 #  elif defined(VGP_x86_darwin)
    /* If we're using memcheck, use these intercepts right from
