@@ -513,7 +513,7 @@ static SyscallTableEntry syscall_main_table[] = {
    GENXY (__NR_read, sys_read),  /* 5000 */
    GENX_ (__NR_write, sys_write),
    GENXY (__NR_open, sys_open),
-   GENXY (__NR_close, sys_close),
+   GENX_ (__NR_close, sys_close),
    GENXY (__NR_stat, sys_newstat),
    GENXY (__NR_fstat, sys_newfstat),
    GENXY (__NR_lstat, sys_newlstat),
@@ -603,7 +603,7 @@ static SyscallTableEntry syscall_main_table[] = {
    GENX_ (__NR_link, sys_link),
    GENX_ (__NR_unlink, sys_unlink),
    GENX_ (__NR_symlink, sys_symlink),
-   GENX_ (__NR_readlink, sys_readlink),
+   GENXY (__NR_readlink, sys_readlink),
    GENX_ (__NR_chmod, sys_chmod),
    GENX_ (__NR_fchmod, sys_fchmod),
    GENX_ (__NR_chown, sys_chown),
@@ -759,7 +759,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_request_key, sys_request_key),
    LINXY (__NR_keyctl, sys_keyctl),
    PLAX_ (__NR_set_thread_area, sys_set_thread_area),
-   LINX_ (__NR_inotify_init, sys_inotify_init),
+   LINXY (__NR_inotify_init, sys_inotify_init),
    LINX_ (__NR_inotify_add_watch, sys_inotify_add_watch),
    LINX_ (__NR_inotify_rm_watch, sys_inotify_rm_watch),
    LINXY (__NR_openat, sys_openat),
@@ -771,7 +771,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_renameat, sys_renameat),
    LINX_ (__NR_linkat, sys_linkat),
    LINX_ (__NR_symlinkat, sys_symlinkat),
-   LINX_ (__NR_readlinkat, sys_readlinkat),
+   LINXY (__NR_readlinkat, sys_readlinkat),
    LINX_ (__NR_fchmodat, sys_fchmodat),
    LINX_ (__NR_faccessat, sys_faccessat),
    LINXY (__NR_pselect6, sys_pselect6),
@@ -800,10 +800,12 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_process_vm_writev, sys_process_vm_writev),
    LINX_ (__NR_sched_setattr, sys_sched_setattr),
    LINXY (__NR_sched_getattr, sys_sched_getattr),
+   LINX_ (__NR_renameat2, sys_renameat2),
    LINXY (__NR_getrandom, sys_getrandom),
    LINXY (__NR_memfd_create, sys_memfd_create),
    LINX_ (__NR_execveat, sys_execveat),
    LINX_ (__NR_membarrier, sys_membarrier),
+   GENX_ (__NR_mlock2, sys_mlock2),
    LINX_ (__NR_copy_file_range, sys_copy_file_range),
    LINXY (__NR_preadv, sys_preadv),
    LINX_ (__NR_pwritev, sys_pwritev),
@@ -811,6 +813,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_pwritev2, sys_pwritev2),
    LINX_ (__NR_syncfs, sys_syncfs),
    LINXY (__NR_statx, sys_statx),
+   GENX_ (__NR_rseq, sys_ni_syscall),
    LINX_ (__NR_setns, sys_setns),
    LINXY (__NR_io_uring_setup, sys_io_uring_setup),
    LINXY (__NR_io_uring_enter, sys_io_uring_enter),
@@ -818,8 +821,11 @@ static SyscallTableEntry syscall_main_table[] = {
    LINXY (__NR_pidfd_open, sys_pidfd_open),
    GENX_ (__NR_clone3, sys_ni_syscall),
    LINXY (__NR_close_range, sys_close_range),
+   LINXY (__NR_openat2, sys_openat2),
+   LINXY (__NR_pidfd_getfd, sys_pidfd_getfd),
    LINX_ (__NR_faccessat2, sys_faccessat2),
    LINXY(__NR_epoll_pwait2, sys_epoll_pwait2),
+   LINX_ (__NR_fchmodat2, sys_fchmodat2),
 };
 
 SyscallTableEntry * ML_(get_linux_syscall_entry) ( UInt sysno )
