@@ -610,7 +610,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_fchownat,               sys_fchownat),
    GENX_ (__NR_fchown,                 sys_fchown),
    LINXY (__NR_openat,                 sys_openat),
-   GENXY (__NR_close,                  sys_close),
+   GENX_ (__NR_close,                  sys_close),
    LINX_ (__NR_vhangup,                sys_vhangup),
    LINXY (__NR_pipe2,                  sys_pipe2),
    LINX_ (__NR_quotactl,               sys_quotactl),
@@ -631,7 +631,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_vmsplice,               sys_vmsplice),
    LINX_ (__NR_splice,                 sys_splice),
    LINX_ (__NR_tee,                    sys_tee),
-   LINX_ (__NR_readlinkat,             sys_readlinkat),
+   LINXY (__NR_readlinkat,             sys_readlinkat),
    GENX_ (__NR_sync,                   sys_sync),
    GENX_ (__NR_fsync,                  sys_fsync),
    GENX_ (__NR_fdatasync,              sys_fdatasync),
@@ -814,7 +814,7 @@ static SyscallTableEntry syscall_main_table[] = {
    LINX_ (__NR_execveat,               sys_execveat),
    //    (__NR_userfaultfd,            sys_ni_syscall),
    LINX_ (__NR_membarrier,             sys_membarrier),
-   //    (__NR_mlock2,                 sys_ni_syscall),
+   GENX_ (__NR_mlock2,                 sys_mlock2),
    //    (__NR_copy_file_range,        sys_ni_syscall),
    //    (__NR_preadv2,                sys_ni_syscall),
    //    (__NR_pwritev2,               sys_ni_syscall),
@@ -824,9 +824,14 @@ static SyscallTableEntry syscall_main_table[] = {
    LINXY (__NR_io_uring_setup,         sys_io_uring_setup),
    LINXY (__NR_io_uring_enter,         sys_io_uring_enter),
    LINXY (__NR_io_uring_register,      sys_io_uring_register),
+   LINXY (__NR_pidfd_open,             sys_pidfd_open),
    GENX_ (__NR_clone3,                 sys_ni_syscall),
    LINXY (__NR_close_range,            sys_close_range),
+   LINXY(__NR_openat2,                 sys_openat2),
+   LINXY(__NR_pidfd_getfd,             sys_pidfd_getfd),
    LINX_ (__NR_faccessat2,             sys_faccessat2),
+   LINXY (__NR_epoll_pwait2,           sys_epoll_pwait2),
+   LINX_ (__NR_fchmodat2,              sys_fchmodat2),
 };
 
 SyscallTableEntry* ML_(get_linux_syscall_entry) (UInt sysno)
