@@ -713,7 +713,7 @@ static SyscallTableEntry syscall_table[] = {
    GENX_(__NR_symlink,           sys_symlink),           // 83
 //..    //   (__NR_oldlstat,          sys_lstat),             // 84 -- obsolete
 //.. 
-   GENX_(__NR_readlink,          sys_readlink),          // 85
+   GENXY(__NR_readlink,          sys_readlink),          // 85
 //..    //   (__NR_uselib,            sys_uselib),            // 86 */Linux
 //..    //   (__NR_swapon,            sys_swapon),            // 87 */Linux
 //..    //   (__NR_reboot,            sys_reboot),            // 88 */Linux
@@ -944,7 +944,7 @@ static SyscallTableEntry syscall_table[] = {
    LINX_(__NR_ioprio_set,        sys_ioprio_set),         // 273
    LINX_(__NR_ioprio_get,        sys_ioprio_get),         // 274
 
-   LINX_(__NR_inotify_init,  sys_inotify_init),               // 275
+   LINXY(__NR_inotify_init,  sys_inotify_init),               // 275
    LINX_(__NR_inotify_add_watch,  sys_inotify_add_watch),     // 276
    LINX_(__NR_inotify_rm_watch,   sys_inotify_rm_watch),      // 277
    PLAXY(__NR_spu_run,            sys_spu_run),               // 278
@@ -963,7 +963,7 @@ static SyscallTableEntry syscall_table[] = {
    LINX_(__NR_renameat,          sys_renameat),          // 293
    LINX_(__NR_linkat,            sys_linkat),            // 294
    LINX_(__NR_symlinkat,         sys_symlinkat),         // 295
-   LINX_(__NR_readlinkat,        sys_readlinkat),        // 296
+   LINXY(__NR_readlinkat,        sys_readlinkat),        // 296
    LINX_(__NR_fchmodat,          sys_fchmodat),          // 297
    LINX_(__NR_faccessat,         sys_faccessat),         // 298
    LINX_(__NR_set_robust_list,   sys_set_robust_list),   // 299
