@@ -607,7 +607,7 @@ static SyscallTableEntry syscall_table[] = {
    GENX_(__NR_write,             sys_write),              //   4
 
    GENXY(__NR_open,              sys_open),               //   5
-   GENXY(__NR_close,             sys_close),              //   6
+   GENX_(__NR_close,             sys_close),              //   6
    GENXY(__NR_waitpid,           sys_waitpid),            //   7
    GENXY(__NR_creat,             sys_creat),              //   8
    GENX_(__NR_link,              sys_link),               //   9
@@ -702,7 +702,7 @@ static SyscallTableEntry syscall_table[] = {
    GENX_(__NR_symlink,           sys_symlink),            //  83
 // _____(__NR_oldlstat,          sys_oldlstat),           //  84
 
-   GENX_(__NR_readlink,          sys_readlink),           //  85
+   GENXY(__NR_readlink,          sys_readlink),           //  85
 // _____(__NR_uselib,            sys_uselib),             //  86
 // _____(__NR_swapon,            sys_swapon),             //  87
 // _____(__NR_reboot,            sys_reboot),             //  88
@@ -928,7 +928,7 @@ static SyscallTableEntry syscall_table[] = {
    LINX_(__NR_ioprio_set,        sys_ioprio_set),         // 273
    LINX_(__NR_ioprio_get,        sys_ioprio_get),         // 274
 
-   LINX_(__NR_inotify_init,  sys_inotify_init),           // 275
+   LINXY(__NR_inotify_init,  sys_inotify_init),           // 275
    LINX_(__NR_inotify_add_watch,  sys_inotify_add_watch), // 276
    LINX_(__NR_inotify_rm_watch,   sys_inotify_rm_watch),  // 277
 
@@ -945,7 +945,7 @@ static SyscallTableEntry syscall_table[] = {
    LINX_(__NR_renameat,          sys_renameat),           // 293
    LINX_(__NR_linkat,            sys_linkat),             // 294
    LINX_(__NR_symlinkat,         sys_symlinkat),          // 295
-   LINX_(__NR_readlinkat,        sys_readlinkat),         // 296
+   LINXY(__NR_readlinkat,        sys_readlinkat),         // 296
    LINX_(__NR_fchmodat,          sys_fchmodat),           // 297
    LINX_(__NR_faccessat,         sys_faccessat),          // 298
    LINX_(__NR_set_robust_list,   sys_set_robust_list),    // 299
@@ -1013,6 +1013,7 @@ static SyscallTableEntry syscall_table[] = {
 
    LINX_(__NR_membarrier,        sys_membarrier),       // 365
 
+   GENX_(__NR_mlock2,            sys_mlock2),           // 378
    LINX_(__NR_copy_file_range,   sys_copy_file_range),  // 379
    LINX_(__NR_preadv2,           sys_preadv2),          // 380
    LINX_(__NR_pwritev2,          sys_pwritev2),         // 381
@@ -1028,10 +1029,13 @@ static SyscallTableEntry syscall_table[] = {
    LINXY(__NR_pidfd_open,        sys_pidfd_open),        // 434
    GENX_(__NR_clone3,            sys_ni_syscall),        // 435
    LINXY(__NR_close_range,       sys_close_range),       // 436
-
+   LINXY(__NR_openat2,           sys_openat2),           // 437
+   LINXY(__NR_pidfd_getfd,       sys_pidfd_getfd),       // 438
    LINX_(__NR_faccessat2,        sys_faccessat2),       // 439
 
    LINXY (__NR_epoll_pwait2,     sys_epoll_pwait2),      // 441
+
+   LINX_ (__NR_fchmodat2,        sys_fchmodat2),         // 452
 };
 
 SyscallTableEntry* ML_(get_linux_syscall_entry) ( UInt sysno )
