@@ -602,107 +602,22 @@ POST(sys_sysarch)
 }
 
 // freebsd6_pread 173
-#if (FREEBSD_VERS <= FREEBSD_10)
-PRE(sys_freebsd6_pread)
-{
-   *flags |= SfMayBlock;
-   PRINT("sys_freebsd6_pread ( %" FMT_REGWORD "u, %#" FMT_REGWORD "x, %" FMT_REGWORD "u, %" FMT_REGWORD "u, %" FMT_REGWORD "u )", ARG1, ARG2, ARG3, ARG5, ARG6);
-   PRE_REG_READ6(ssize_t, "pread",
-                 unsigned int, fd, char *, buf, vki_size_t, count,
-                 int, pad, unsigned int, off_low, unsigned int, off_high);
-
-   if (!ML_(fd_allowed)(ARG1, "freebsd6_pread", tid, False))
-      SET_STATUS_Failure( VKI_EBADF );
-   else
-      PRE_MEM_WRITE( "freebsd6_pread(buf)", ARG2, ARG3 );
-}
-
-POST(sys_freebsd6_pread)
-{
-   vg_assert(SUCCESS);
-   POST_MEM_WRITE( ARG2, RES );
-}
-#endif
+// removed
 
 // freebsd6_pwrite 174
-#if (FREEBSD_VERS <= FREEBSD_10)
-PRE(sys_freebsd6_pwrite)
-{
-   Bool ok;
-   *flags |= SfMayBlock;
-   PRINT("sys_freebsd6_pwrite ( %" FMT_REGWORD "u, %#" FMT_REGWORD "x, %" FMT_REGWORD "u, %" FMT_REGWORD "u, %" FMT_REGWORD "u )", ARG1, ARG2, ARG3, ARG5, ARG6);
-   PRE_REG_READ6(ssize_t, "freebsd6_pwrite",
-                 unsigned int, fd, const char *, buf, vki_size_t, count,
-                 int, pad, unsigned int, off_low, unsigned int, off_high);
-   /* check to see if it is allowed.  If not, try for an exemption from
-      --sim-hints=enable-outer (used for self hosting). */
-   ok = ML_(fd_allowed)(ARG1, "freebsd6_pwrite", tid, False);
-   if (!ok && ARG1 == 2/*stderr*/
-         && SimHintiS(SimHint_enable_outer, VG_(clo_sim_hints)))
-      ok = True;
-   if (!ok)
-      SET_STATUS_Failure( VKI_EBADF );
-   else
-      PRE_MEM_READ( "freebsd6_write(buf)", ARG2, ARG3 );
-}
-#endif
+// removed
 
 // SYS_freebsd6_mmap 197
-#if (FREEBSD_VERS <= FREEBSD_10)
-/* This is here because on x86 the off_t is passed in 2 regs. Don't ask about pad.  */
-
-/* caddr_t mmap(caddr_t addr, size_t len, int prot, int flags, int fd, int pad, off_t pos); */
-/*              ARG1           ARG2       ARG3      ARG4       ARG5    ARG6     ARG7+ARG8 */
-
-PRE(sys_freebsd6_mmap)
-{
-   SysRes r;
-
-   PRINT("sys_freebsd6_mmap ( %#" FMT_REGWORD "x, %" FMT_REGWORD "u, %" FMT_REGWORD "u, %" FMT_REGWORD "u, %" FMT_REGWORD "u, pad%" FMT_REGWORD "u, lo0x%" FMT_REGWORD "x hi0x%" FMT_REGWORD "x)",
-         ARG1, (UWord)ARG2, ARG3, ARG4, ARG5, ARG6, ARG7, ARG8 );
-   PRE_REG_READ8(long, "mmap",
-                 char *, addr, unsigned long, len, int, prot,  int, flags,
-                 int, fd,  int, pad, unsigned long, lo, unsigned long, hi);
-
-   r = ML_(generic_PRE_sys_mmap)( tid, ARG1, ARG2, ARG3, ARG4, ARG5, MERGE64(ARG7,ARG8) );
-   SET_STATUS_from_SysRes(r);
-}
-#endif
+// removed
 
 // freebsd6_lseek 199
-#if (FREEBSD_VERS <= FREEBSD_10)
-PRE(sys_freebsd6_lseek)
-{
-   PRINT("sys_freebsd6_lseek ( %" FMT_REGWORD "u, 0x%" FMT_REGWORD "x, 0x%" FMT_REGWORD "x, %" FMT_REGWORD "u )", ARG1,ARG3,ARG4,ARG5);
-   PRE_REG_READ5(long, "lseek",
-                 unsigned int, fd, int, pad, unsigned int, offset_low,
-                 unsigned int, offset_high, unsigned int, whence);
-}
-#endif
+// removed
 
 // freebsd6_truncate 200
-#if (FREEBSD_VERS <= FREEBSD_10)
-PRE(sys_freebsd6_truncate)
-{
-   *flags |= SfMayBlock;
-   PRINT("sys_truncate ( %#" FMT_REGWORD "x(%s), %" FMT_REGWORD "u, %" FMT_REGWORD "u )", ARG1,(char *)ARG1,ARG3,ARG4);
-   PRE_REG_READ4(long, "truncate",
-                 const char *, path, int, pad,
-                 unsigned int, length_low, unsigned int, length_high);
-   PRE_MEM_RASCIIZ( "truncate(path)", ARG1 );
-}
-#endif
+// removed
 
 // freebsd6_ftruncate 201
-#if (FREEBSD_VERS <= FREEBSD_10)
-PRE(sys_freebsd6_ftruncate)
-{
-   *flags |= SfMayBlock;
-   PRINT("sys_ftruncate ( %" FMT_REGWORD "u, %" FMT_REGWORD "u, %" FMT_REGWORD "u )", ARG1,ARG3,ARG4);
-   PRE_REG_READ4(long, "ftruncate", unsigned int, fd, int, pad,
-                 unsigned int, length_low, unsigned int, length_high);
-}
-#endif
+// removed
 
 // SYS_clock_getcpuclockid2   247
 // no manpage for this, from syscalls.master
@@ -1392,12 +1307,8 @@ POST(sys_wait6)
    }
 }
 
-// the man page is inconsistent for the last argument
-// See https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=247386
-// will stick to 'arg' for simplicity
-
 // SYS_procctl 544
-// int procctl(idtype_t idtype, id_t id, int cmd, void *arg);
+// int procctl(idtype_t idtype, id_t id, int cmd, void *data);
 PRE(sys_procctl)
 {
    PRINT("sys_procctl ( %" FMT_REGWORD "d, %llu, %" FMT_REGWORD"d, %#" FMT_REGWORD "x )",
@@ -1405,7 +1316,7 @@ PRE(sys_procctl)
    PRE_REG_READ5(int, "procctl", vki_idtype_t, idtype,
                  vki_uint32_t, MERGE64_FIRST(id),
                  vki_uint32_t, MERGE64_SECOND(id),
-                 int, cmd, void *, arg);
+                 int, cmd, void *, data);
    switch (ARG4) {
    case VKI_PROC_ASLR_CTL:
    case VKI_PROC_SPROTECT:
@@ -1415,13 +1326,13 @@ PRE(sys_procctl)
    case VKI_PROC_STACKGAP_CTL:
    case VKI_PROC_NO_NEW_PRIVS_CTL:
    case VKI_PROC_WXMAP_CTL:
-      PRE_MEM_READ("procctl(arg)", ARG5, sizeof(int));
+      PRE_MEM_READ("procctl(data)", ARG5, sizeof(int));
       break;
    case VKI_PROC_REAP_STATUS:
-      PRE_MEM_READ("procctl(arg)", ARG5, sizeof(struct vki_procctl_reaper_status));
+      PRE_MEM_READ("procctl(data)", ARG5, sizeof(struct vki_procctl_reaper_status));
       break;
    case VKI_PROC_REAP_GETPIDS:
-      PRE_MEM_READ("procctl(arg)", ARG5, sizeof(struct vki_procctl_reaper_pids));
+      PRE_MEM_READ("procctl(data)", ARG5, sizeof(struct vki_procctl_reaper_pids));
       break;
    case VKI_PROC_REAP_KILL:
       /* The first three fields are reads
@@ -1435,15 +1346,15 @@ PRE(sys_procctl)
        *
        * There is also a pad field
        */
-      PRE_MEM_READ("procctl(arg)", ARG5, sizeof(int) + sizeof(u_int) + sizeof(vki_pid_t));
-      PRE_MEM_WRITE("procctl(arg)", ARG5+offsetof(struct vki_procctl_reaper_kill, rk_killed), sizeof(u_int) + sizeof(vki_pid_t));
+      PRE_MEM_READ("procctl(data)", ARG5, sizeof(int) + sizeof(u_int) + sizeof(vki_pid_t));
+      PRE_MEM_WRITE("procctl(data)", ARG5+offsetof(struct vki_procctl_reaper_kill, rk_killed), sizeof(u_int) + sizeof(vki_pid_t));
       break;
    case VKI_PROC_ASLR_STATUS:
    case VKI_PROC_PDEATHSIG_STATUS:
    case VKI_PROC_STACKGAP_STATUS:
    case VKI_PROC_TRAPCAP_STATUS:
    case VKI_PROC_TRACE_STATUS:
-      PRE_MEM_WRITE("procctl(arg)", ARG5, sizeof(int));
+      PRE_MEM_WRITE("procctl(data)", ARG5, sizeof(int));
    case VKI_PROC_REAP_ACQUIRE:
    case VKI_PROC_REAP_RELEASE:
    default:
@@ -1480,8 +1391,6 @@ PRE(sys_mknodat)
    PRE_MEM_RASCIIZ( "mknodat(pathname)", ARG2 );
 }
 
-#if (FREEBSD_VERS >= FREEBSD_12)
-
 // SYS_cpuset_getdomain 561
 // int cpuset_getdomain(cpulevel_t level, cpuwhich_t which, id_t id,
 //                      size_t setsize, domainset_t *mask, int *policy);
@@ -1521,8 +1430,6 @@ PRE(sys_cpuset_setdomain)
    PRE_MEM_READ( "cpuset_getdomain(mask)", ARG6, ARG5 );
 }
 
-#endif
-
 PRE(sys_fake_sigreturn)
 {
    /* See comments on PRE(sys_rt_sigreturn) in syswrap-amd64-linux.c for
