@@ -44,6 +44,11 @@ extern Int VG_(fcntl)   ( Int fd, Int cmd, Addr arg );
 /* Convert an fd into a filename */
 extern Bool VG_(resolve_filename) ( Int fd, const HChar** buf );
 
+#if defined(VGO_freebsd)
+/* get the flags used to obtain an fd */
+extern Bool VG_(resolve_filemode) ( Int fd, Int * result );
+#endif
+
 /* Return the size of a file, or -1 in case of error */
 extern Long VG_(fsize) ( Int fd );
 
@@ -105,6 +110,10 @@ extern Int VG_(mkstemp) ( const HChar* part_of_name, /*OUT*/HChar* fullname );
    return if the working directory couldn't be found.  */
 extern void VG_(record_startup_wd) ( void );
 
+#if defined(VGO_freebsd)
+extern Bool VG_(realpath)(const HChar *path, HChar *resolved);
+#endif
+
 #endif   // __PUB_CORE_LIBCFILE_H
 
 /*--------------------------------------------------------------------*/
