@@ -1,7 +1,7 @@
 /*
   This file is part of drd, a thread error detector.
 
-  Copyright (C) 2006-2017 Bart Van Assche <bvanassche@acm.org>.
+  Copyright (C) 2006-2020 Bart Van Assche <bvanassche@acm.org>.
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -66,7 +66,7 @@ static Bool s_first_race_only      = False;
 
 /* Function definitions. */
 
-Bool DRD_(get_check_stack_accesses)()
+Bool DRD_(get_check_stack_accesses)(void)
 {
    return s_check_stack_accesses;
 }
@@ -77,7 +77,7 @@ void DRD_(set_check_stack_accesses)(const Bool c)
    s_check_stack_accesses = c;
 }
 
-Bool DRD_(get_first_race_only)()
+Bool DRD_(get_first_race_only)(void)
 {
    return s_first_race_only;
 }
