@@ -21,9 +21,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
    The GNU General Public License is contained in the file COPYING.
 */
@@ -104,6 +102,8 @@ typedef  Word                 PtrdiffT;   // 32             64
 // always a signed 64-bit int.  So we defined our own Off64T as well.
 #if defined(VGO_linux) || defined(VGO_solaris)
 typedef Word                   OffT;      // 32             64
+#elif defined(VGO_freebsd)
+typedef Long                   OffT;      // 64             64
 #elif defined(VGO_darwin)
 typedef Long                   OffT;      // 64             64
 #else
@@ -227,6 +227,14 @@ typedef
       SysResMode _mode;
    }
    SysRes;
+#elif defined(VGO_freebsd)
+typedef
+   struct {
+      UWord _val;
+      UWord _val2;
+      Bool  _isError;
+   }
+   SysRes;
 
 #elif defined(VGO_solaris)
 typedef
@@ -296,7 +304,11 @@ static inline UWord sr_Res ( SysRes sr ) {
    return sr._isError ? 0 : sr._val;
 }
 static inline UWord sr_Err ( SysRes sr ) {
+#if defined(VGP_nanomips_linux)
+   return sr._isError ? -sr._val : 0;
+#else
    return sr._isError ? sr._val : 0;
+#endif
 }
 static inline Bool sr_EQ ( UInt sysno, SysRes sr1, SysRes sr2 ) {
    /* sysno is ignored for Linux/not-MIPS */
@@ -304,6 +316,27 @@ static inline Bool sr_EQ ( UInt sysno, SysRes sr1, SysRes sr2 ) {
           && sr1._isError == sr2._isError;
 }
 
+#elif defined(VGO_freebsd)
+
+static inline Bool sr_isError ( SysRes sr ) {
+   return sr._isError;
+}
+static inline UWord sr_Res ( SysRes sr ) {
+   return sr._isError ? 0 : sr._val;
+}
+static inline UWord sr_ResHI ( SysRes sr ) {
+   return sr._isError ? 0 : sr._val2;
+}
+static inline UWord sr_Err ( SysRes sr ) {
+   return sr._isError ? sr._val : 0;
+}
+static inline Bool sr_EQ ( UInt sysno, SysRes sr1, SysRes sr2 ) {
+   return sr_Res(sr1) == sr_Res(sr2) 
+          && sr_ResHI(sr1) == sr_ResHI(sr2)
+          && ((sr_isError(sr1) && sr_isError(sr2)) 
+              || (!sr_isError(sr1) && !sr_isError(sr2)));
+}
+
 #elif defined(VGO_darwin)
 
 static inline Bool sr_isError ( SysRes sr ) {
@@ -403,11 +436,12 @@ static inline Bool sr_EQ ( UInt sysno, SysRes sr1, SysRes sr2 ) {
 #undef VG_LITTLEENDIAN
 
 #if defined(VGA_x86) || defined(VGA_amd64) || defined (VGA_arm) \
-    || ((defined(VGA_mips32) || defined(VGA_mips64)) && defined (_MIPSEL)) \
-    || defined(VGA_arm64)  || defined(VGA_ppc64le)
+    || ((defined(VGA_mips32) || defined(VGA_mips64) || defined(VGA_nanomips)) \
+    && defined (_MIPSEL)) || defined(VGA_arm64)  || defined(VGA_ppc64le)
 #  define VG_LITTLEENDIAN 1
 #elif defined(VGA_ppc32) || defined(VGA_ppc64be) || defined(VGA_s390x) \
-      || ((defined(VGA_mips32) || defined(VGA_mips64)) && defined (_MIPSEB))
+      || ((defined(VGA_mips32) || defined(VGA_mips64) || defined(VGA_nanomips)) \
+      && defined (_MIPSEB))
 #  define VG_BIGENDIAN 1
 #else
 #  error Unknown arch
@@ -451,7 +485,7 @@ static inline Bool sr_EQ ( UInt sysno, SysRes sr1, SysRes sr2 ) {
       || defined(VGA_ppc64be) || defined(VGA_ppc64le) \
       || defined(VGA_arm) || defined(VGA_s390x) \
       || defined(VGA_mips32) || defined(VGA_mips64) \
-      || defined(VGA_arm64)
+      || defined(VGA_arm64) || defined(VGA_nanomips)
 #  define VG_REGPARM(n)            /* */
 #else
 #  error Unknown arch
