@@ -60,7 +60,7 @@
    The call to MARK_STACK_NO_EXEC should be put unconditionally
    at the end of all asm source files.
 */
-#if defined(VGO_linux)
+#if defined(VGO_linux) || defined(VGO_freebsd)
 #  if defined(VGA_arm)
 #    define MARK_STACK_NO_EXEC .section .note.GNU-stack,"",%progbits
 #  else
