@@ -23,9 +23,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
    The GNU General Public License is contained in the file COPYING.
 */
@@ -46,7 +44,6 @@ extern const HChar *VG_(sysnum_string) (Word sysnum);
 // Macro provided for backward compatibility purposes.
 #define VG_SYSNUM_STRING(sysnum) VG_(sysnum_string)(sysnum)
 
-
 #endif   // __PUB_TOOL_VKISCNUMS_H
 
 /*--------------------------------------------------------------------*/
