@@ -7,7 +7,7 @@
    This file is part of Valgrind, a dynamic binary instrumentation
    framework.
 
-   Copyright (C) 2007-2013 Apple Inc.
+   Copyright (C) 2007-2017 Apple Inc.
       Greg Parker  gparker@apple.com
 
    This program is free software; you can redistribute it and/or
@@ -21,9 +21,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307, USA.
+   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
    The GNU General Public License is contained in the file COPYING.
 */
@@ -34,6 +32,12 @@
 #ifndef __VKI_DARWIN_H
 #define __VKI_DARWIN_H
 
+/* struct __darwin_ucontext isn't fully declared without
+ * this definition.  It's crazy but there it is.  */
+#ifndef _XOPEN_SOURCE
+#define _XOPEN_SOURCE 0500
+#endif
+
 #include <stdint.h>
 
 #define vki_int8_t int8_t
@@ -106,6 +110,8 @@ typedef uint32_t vki_u32;
 
 #define vki_timeval timeval
 #define vki_timeval32 timeval32
+#define vki_tv_sec tv_sec
+#define vki_tv_usec tv_usec
 #define vki_timespec timespec
 #define vki_itimerval itimerval
 #define vki_timezone timezone
@@ -268,6 +274,8 @@ typedef uint32_t vki_u32;
 #define	VKI_O_EXCL	O_EXCL
 #define	VKI_O_EVTONLY	O_EVTONLY
 
+#define VKI_AT_FDCWD AT_FDCWD
+
 #define	VKI_F_DUPFD	F_DUPFD
 #define	VKI_F_GETFD	F_GETFD
 #define	VKI_F_SETFD	F_SETFD
@@ -278,6 +286,9 @@ typedef uint32_t vki_u32;
 #define	VKI_F_GETLK	F_GETLK
 #define	VKI_F_SETLK	F_SETLK
 #define	VKI_F_SETLKW	F_SETLKW
+#if DARWIN_VERS >= DARWIN_10_10
+#define	VKI_F_SETLKWTIMEOUT F_SETLKWTIMEOUT
+#endif
 
 #define VKI_F_CHKCLEAN	F_CHKCLEAN
 #define VKI_F_PREALLOCATE	F_PREALLOCATE
@@ -293,6 +304,11 @@ typedef uint32_t vki_u32;
 #if DARWIN_VERS >= DARWIN_10_9
 # define VKI_F_ADDFILESIGS  F_ADDFILESIGS
 #endif
+#if DARWIN_VERS >= DARWIN_10_11
+# define VKI_F_ADDFILESIGS_FOR_DYLD_SIM  F_ADDFILESIGS_FOR_DYLD_SIM
+# define VKI_F_BARRIERFSYNC              F_BARRIERFSYNC
+# define VKI_F_ADDFILESIGS_RETURN        F_ADDFILESIGS_RETURN
+#endif
 #define VKI_F_FULLFSYNC	F_FULLFSYNC
 #define VKI_F_PATHPKG_CHECK	F_PATHPKG_CHECK
 #define VKI_F_FREEZE_FS	F_FREEZE_FS
@@ -511,6 +527,12 @@ typedef
 #define VKI_BUS_ADRERR   BUS_ADRERR
 #define VKI_BUS_OBJERR   BUS_OBJERR
 #define VKI_TRAP_BRKPT   TRAP_BRKPT
+#define VKI_CLD_EXITED   CLD_EXITED
+#define VKI_CLD_KILLED   CLD_KILLED
+#define VKI_CLD_DUMPED   CLD_DUMPED
+#define VKI_CLD_TRAPPED  CLD_TRAPPED
+#define VKI_CLD_STOPPED  CLD_STOPPED
+#define VKI_CLD_CONTINUED CLD_CONTINUED
 
 /* JRS: not 100% sure, but I think these two are correct */
 #define VKI_SA_ONESHOT   SA_RESETHAND
@@ -791,6 +813,19 @@ typedef
 #define vki_kevent kevent
 #define vki_kevent64 kevent64_s
 
+// xnu_root/bsd/sys/event.h
+
+struct vki_kevent_qos_s {
+    uint64_t    ident;      /* identifier for this event */
+    int16_t     filter;     /* filter for event */
+    uint16_t    flags;      /* general flags */
+    int32_t     qos;        /* quality of service */
+    uint64_t    udata;      /* opaque user data identifier */
+    uint32_t    fflags;     /* filter-specific flags */
+    uint32_t    xflags;     /* extra filter-specific flags */
+    int64_t     data;       /* filter-specific data */
+    uint64_t    ext[4];     /* filter-specific extensions */
+};
 
 #include <sys/ev.h>
 
@@ -831,14 +866,19 @@ struct ByteRangeLockPB2
 #define VKI_FSIOC_SYNC_VOLUME        _IOW('A', 1, uint32_t)
 
 
-// Libc/pthreads/pthread.c
+// libpthread/kern/workqueue_internal.h
 
-#define VKI_WQOPS_QUEUE_ADD          1
-#define VKI_WQOPS_QUEUE_REMOVE       2
-#define VKI_WQOPS_THREAD_RETURN      4
-#define VKI_WQOPS_THREAD_SETCONC     8
-#define VKI_WQOPS_QUEUE_NEWSPISUPP  16  /* check for newer SPI support */
-#define VKI_WQOPS_QUEUE_REQTHREADS  32  /* request number of threads of a prio */
+#define VKI_WQOPS_QUEUE_ADD                    1
+#define VKI_WQOPS_QUEUE_REMOVE                 2
+#define VKI_WQOPS_THREAD_RETURN                4  /* parks the thread back into the kernel */
+#define VKI_WQOPS_THREAD_SETCONC               8
+#define VKI_WQOPS_QUEUE_NEWSPISUPP            16  /* check for newer SPI support */
+#define VKI_WQOPS_QUEUE_REQTHREADS            32  /* request number of threads of a prio */
+#define VKI_WQOPS_QUEUE_REQTHREADS2           48  /* request a number of threads in a given priority bucket */
+#define VKI_WQOPS_THREAD_KEVENT_RETURN        64  /* parks the thread after delivering the passed kevent array */
+#define VKI_WQOPS_SET_EVENT_MANAGER_PRIORITY 128  /* max() in the provided priority in the the priority of the event manager */
+#define VKI_WQOPS_THREAD_WORKLOOP_RETURN     256  /* parks the thread after delivering the passed kevent array */
+#define VKI_WQOPS_SHOULD_NARROW              512  /* checks whether we should narrow our concurrency */
 
 
 #include <sys/ttycom.h>
@@ -992,6 +1032,23 @@ struct ByteRangeLockPB2
 #define VKI_DTRACEHIOC_ADDDOF   DTRACEHIOC_ADDDOF
 
 
+#include <net/bpf.h>
+
+#define vki_bpf_program bpf_program
+#define vki_bf_len bf_len
+#define vki_bf_insns bf_insns
+#define vki_bpf_dltlist bpf_dltlist
+#define vki_bfl_len bfl_len
+#define vki_bfl_list bfl_list
+
+#define VKI_BIOCSETF        BIOCSETF
+#define VKI_BIOCFLUSH       BIOCFLUSH
+#define VKI_BIOCPROMISC     BIOCPROMISC
+#define VKI_BIOCSETIF       BIOCSETIF
+#define VKI_BIOCSRTIMEOUT   BIOCSRTIMEOUT
+#define VKI_BIOCGDLTLIST    BIOCGDLTLIST
+
+
 #include <sys/ucontext.h>
 
 /* quite why sys/ucontext.h provides a 'struct __darwin_ucontext'
@@ -1062,4 +1119,100 @@ struct ByteRangeLockPB2
 //#define vki_errno_t
 typedef int vki_errno_t;
 
+
+/* necp stuff.  This doesn't appear to exist in any user space include
+   file. */
+#if DARWIN_VERS >= DARWIN_10_10
+struct vki_necp_aggregate_result {
+   vki_u_int32_t field1;
+   unsigned int  field2;
+   vki_u_int32_t field3;
+   vki_u_int32_t field4;
+   vki_uuid_t    field5;
+   u_int32_t     field6;
+   u_int32_t     field7;
+};
+
+#define VKI_CSR_CHECK 0
+#define VKI_CSR_GET_ACTIVE_CONFIG 1
+#endif /* DARWIN_VERS >= DARWIN_10_10 */
+
+#if DARWIN_VERS >= DARWIN_10_12
+// ulock_wake & ulock_wait operations
+#define VKI_UL_OPCODE_MASK      0x000000FF
+#define VKI_UL_FLAGS_MASK       0xFFFFFF00
+#define VKI_UL_COMPARE_AND_WAIT 1
+#define VKI_UL_UNFAIR_LOCK      2
+// ulock_wake & ulock_wait flags
+#define ULF_NO_ERRNO            0x01000000
+
+// ulock_wake flags
+#define VKI_ULF_WAKE_ALL          0x00000100
+#define VKI_ULF_WAKE_THREAD       0x00000200
+
+// ulock_wait flags
+#define WKI_ULF_WAIT_WORKQ_DATA_CONTENTION	0x00010000
+
+#define VKI_NECP_CLIENT_ACTION_ADD                     1
+#define VKI_NECP_CLIENT_ACTION_REMOVE                  2
+#define VKI_NECP_CLIENT_ACTION_COPY_PARAMETERS         3
+#define VKI_NECP_CLIENT_ACTION_COPY_RESULT             4
+#define VKI_NECP_CLIENT_ACTION_COPY_LIST               5
+#define VKI_NECP_CLIENT_ACTION_AGENT                   7
+#define VKI_NECP_CLIENT_ACTION_COPY_AGENT              8
+#define VKI_NECP_CLIENT_ACTION_COPY_INTERFACE          9
+#define VKI_NECP_CLIENT_ACTION_COPY_ROUTE_STATISTICS  11
+#define VKI_NECP_CLIENT_ACTION_AGENT_USE              12
+#define VKI_NECP_CLIENT_ACTION_UPDATE_CACHE           14
+#define VKI_NECP_CLIENT_ACTION_COPY_CLIENT_UPDATE     15
+#define VKI_NECP_CLIENT_ACTION_COPY_UPDATED_RESULT    16
+#define VKI_NECP_CLIENT_ACTION_CLAIM                  19
+#define VKI_NECP_CLIENT_ACTION_SIGN                   20
+
+#define VKI_NECP_MAX_CLIENT_PARAMETERS_SIZE    1024
+#define VKI_NECP_CLIENT_ACTION_SIGN_TAG_LENGTH   32
+
+#define VKI_IFXNAMSIZ     IFNAMSIZ + 8
+#define VKI_IFNET_SIGNATURELEN      20
+
+struct vki_necp_client_signable {
+	uuid_t client_id;
+	u_int32_t sign_type;
+} __attribute__((__packed__));
+
+struct vki_necp_cache_buffer {
+	u_int8_t                necp_cache_buf_type;    //  NECP_CLIENT_CACHE_TYPE_*
+	u_int8_t                necp_cache_buf_ver;     //  NECP_CLIENT_CACHE_TYPE_*_VER
+	u_int32_t               necp_cache_buf_size;
+	mach_vm_address_t       necp_cache_buf_addr;
+};
+
+struct vki_necp_interface_signature {
+  u_int8_t signature[VKI_IFNET_SIGNATURELEN];
+  u_int8_t signature_len;
+};
+
+struct vki_necp_interface_details_legacy {
+	char name[VKI_IFXNAMSIZ];
+	u_int32_t index;
+	u_int32_t generation;
+	u_int32_t functional_type;
+	u_int32_t delegate_index;
+	u_int32_t flags; // see NECP_INTERFACE_FLAG_*
+	u_int32_t mtu;
+	struct vki_necp_interface_signature ipv4_signature;
+	struct vki_necp_interface_signature ipv6_signature;
+};
+
+struct vki_necp_agent_use_parameters {
+	uuid_t agent_uuid;
+	uint64_t out_use_count;
+};
+
+// Precalculated as the struct are really big
+#define VKI_IFNET_STATS_PER_FLOW_SIZE 96
+#define VKI_NECP_STAT_COUNTS_SIZE 68
+
+#endif /* DARWIN_VERS >= DARWIN_10_12 */
+
 #endif
