@@ -16,7 +16,7 @@
 #include <unistd.h>
 #include <sys/regset.h>
 #include <sys/syscall.h>
-#include <sys/ucontext.h>
+#include <ucontext.h>
 
 #define OBIT(rflags) (!!((rflags) & (1 << 11)))
 #define SBIT(rflags) (!!((rflags) & (1 << 7)))
