@@ -5,9 +5,25 @@
 
 int main(void)
 {
-#if defined(MUSL_LIBC)
+#if defined (HAVE_GNU_LIBC_C17_ALIGNED_ALLOC)
    char* p = NULL;
 
+   // zero size
+   p = aligned_alloc(0, 8);
+   assert(p == NULL);
+
+   // non multiple of alignment
+   p = aligned_alloc(8, 25);
+   assert(p && ((size_t)p % 8U == 0U));
+   free(p);
+
+   // align not power of 2
+   p = aligned_alloc(40, 160);
+   assert(p == NULL);
+   errno = 0;
+#endif
+#if defined(MUSL_LIBC)
+   char* p = NULL;
 
    // zero size
    p = aligned_alloc(0, 8);
