@@ -40,16 +40,13 @@ void setupHandlers()
 
 int main()
 {
-    int i;
     char buffer[200];
-    size_t dummy_size_t;
     setupHandlers();
     FILE *p = popen("echo Hallo World", "r");
     while (!feof(p)) {
         int n = fread(buffer, 200, 1, p);
-        dummy_size_t = write(2, buffer, n);
+        __attribute__((unused)) ssize_t nw = write(2, buffer, n);
     }
-    fclose(p);
-    for (i = 0; i < 1000000; i++) ;
+    pclose(p);
     return 0;
 }
