@@ -24,7 +24,7 @@ flogr1(unsigned long input, unsigned long *bitpos, unsigned long *modval,
                   "ipm   %[psw]\n\t"
                   "stg   2, %[bitpos]\n\t"
                   "stg   3, %[modval]\n\t"
-                  : [bitpos]"=m"(*bitpos), [modval]"=m"(*modval),
+                  : [bitpos]"=T"(*bitpos), [modval]"=T"(*modval),
                     [psw]"=&d"(psw)
                   : [val] "d"(value)
                   : "2", "3", "cc");
@@ -48,7 +48,7 @@ flogr2(unsigned long input, unsigned long *bitpos, unsigned long *modval,
                   "ipm   %[psw]\n\t"
                   "stg   2, %[bitpos]\n\t"
                   "stg   3, %[modval]\n\t"
-                  : [bitpos]"=m"(*bitpos), [modval]"=m"(*modval),
+                  : [bitpos]"=T"(*bitpos), [modval]"=T"(*modval),
                     [psw]"=&d"(psw), [val] "+d"(value)
                   :
                   : "3", "cc");
@@ -72,7 +72,7 @@ flogr3(unsigned long input, unsigned long *bitpos, unsigned long *modval,
                   "ipm   %[psw]\n\t"
                   "stg   2, %[bitpos]\n\t"
                   "stg   3, %[modval]\n\t"
-                  : [bitpos]"=m"(*bitpos), [modval]"=m"(*modval),
+                  : [bitpos]"=T"(*bitpos), [modval]"=T"(*modval),
                     [psw]"=&d"(psw), [val] "+d"(value)
                   :
                   : "2", "cc");
